# Changelog

## [0.2.1](https://github.com/contagon/borg2mqtt/compare/v0.2.0...v0.2.1) (2026-02-11)


### Bug Fixes

* Force release please to run ([9756887](https://github.com/contagon/borg2mqtt/commit/9756887492258660e0bd0566a3ee3525e7b7ad13))

## [0.2.0](https://github.com/contagon/borg2mqtt/compare/v0.1.2...v0.2.0) (2026-02-11)


### ⚠ BREAKING CHANGES

* Update to new MQTT default_entity_id ([#6](https://github.com/contagon/borg2mqtt/issues/6))

### Features

* add option for ssh key and fix bug with time format ([26c2d33](https://github.com/contagon/borg2mqtt/commit/26c2d33523d4f15f8c2ca05bba5449d41bd378de))
* Update to new MQTT default_entity_id ([#6](https://github.com/contagon/borg2mqtt/issues/6)) ([d3e1e8a](https://github.com/contagon/borg2mqtt/commit/d3e1e8ad731ee45b9a725c132df3377af326385f))
* Upgrade everything! ([#5](https://github.com/contagon/borg2mqtt/issues/5)) ([5ad3479](https://github.com/contagon/borg2mqtt/commit/5ad347948d0c9938acab582e63fcda4006026e04))
